==> tuia-client-0.8.14-lrb-20190723.063800-1-sources.jar: cn/com/tuia/advert/cache/RedisCommonKeys.java <==
/**
 * Project Name:tuia-core-api
 * File Name:RedisCommonKeys.java
 * Package Name:cn.com.duiba.tuia.core.api.constant
 * Date:2017年3月7日下午6:46:21
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.tuia.advert.cache;

/**
 * ClassName:RedisCommonKeys <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2017年3月7日 下午6:46:21 <br/>
 * @author   zp
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public enum RedisCommonKeys {
    /**广告有效列表*/
    KC101,
    /**广告券码详情缓存*/
    KC103,
    /**广告缓存*/
    KC104,
    /**app缓存*/
    KC105,
    /**应用白名单缓存，key为appId*/
    KC106,
    /**应用白名单缓存,key为appId和策略Id等*/
    KC107,
    /**机器取一个机器ID，用redis做自增*/
    KC118,
    /***用户缓存key*/
    KC119,
    /***增加预算变成可投的广告*/
    KC120,
    /***广告扣费ONS发送失败后，降级走redis扣费*/
    KC121,
    /**特殊权重媒体key*/
    KC122,
    /**落地页待审核*/
    KC123,
    /** 付费有效广告缓存*/
    KC124,
    /** 免费有效广告缓存*/
    KC125,
    /** slot缓存 **/
    KC126,
    /** 广告位白名单缓存 key位slotId **/
    KC127,
    /**广告位白名单缓存,key为slotId和策略Id等*/
    KC128,
    /** 素材ID对应的测试落地页链接 **/
    KC129,
    /** slot流量策略缓存，key为slotId**/
    KC130,
    /** 试投素材点击量*/
    KC131,
    /** es降级消息key前缀，预留 **/
    KC132,
    /** 全局流量缓存*/
    KC133,
    /** 新媒体可测试广告缓存*/
    KC134,
    /**新广告扶持数据缓存*/
    KC135,
    /** 风控定向导量广告位缓存 */
    KC136,
    /** 潜力广告测试数据缓存 */
    KC137,
    /** 应急广告填充配置是否发券缓存 */
    KC138,
    ;
    
    /**
     * 应用标识 tuia-core
     */
    private static final String APPNAME = "TUIA";
    
    public String toString() {
        return APPNAME + "_" + super.toString();
    }
}

==> tuia-client-0.8.85-lrb-20200506.125232-4-sources.jar: cn/com/tuia/advert/cache/RedisCommonKeys.java <==
/**
 * Project Name:tuia-core-api
 * File Name:RedisCommonKeys.java
 * Package Name:cn.com.duiba.tuia.core.api.constant
 * Date:2017年3月7日下午6:46:21
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.tuia.advert.cache;

/**
 * ClassName:RedisCommonKeys <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2017年3月7日 下午6:46:21 <br/>
 * @author   zp
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public enum RedisCommonKeys {
    /**广告有效列表*/
    KC101,
    /**广告券码详情缓存*/
    KC103,
    /**广告缓存*/
    KC104,
    /**app缓存*/
    KC105,
    /**应用白名单缓存，key为appId*/
    KC106,
    /**应用白名单缓存,key为appId和策略Id等*/
    KC107,
    /**机器取一个机器ID，用redis做自增*/
    KC118,
    /***用户缓存key*/
    KC119,
    /***增加预算变成可投的广告*/
    KC120,
    /***广告扣费ONS发送失败后，降级走redis扣费*/
    KC121,
    /**特殊权重媒体key*/
    KC122,
    /**落地页待审核*/
    KC123,
    /** 付费有效广告缓存*/
    KC124,
    /** 免费有效广告缓存*/
    KC125,
    /** slot缓存 **/
    KC126,
    /** 广告位白名单缓存 key位slotId **/
    KC127,
    /**广告位白名单缓存,key为slotId和策略Id等*/
    KC128,
    /** 素材ID对应的测试落地页链接 **/
    KC129,
    /** slot流量策略缓存，key为slotId**/
    KC130,
    /** 试投素材点击量*/
    KC131,
    /** es降级消息key前缀，预留 **/
    KC132,
    /** 全局流量缓存*/
    KC133,
    /** 新媒体可测试广告缓存*/
    KC134,
    /**新广告扶持数据缓存*/
    KC135,
    /** 风控定向导量广告位缓存 */
    KC136,
    /** 潜力广告测试数据缓存 */
    KC137,
    /** 应急广告填充配置是否发券缓存 */
    KC138,
    /**托管底价实时通知*/
    KC139,
    /**广告包名和应用名缓存*/
    KC140,
    /** 广告扩展表*/
    KC141,
    /** 广告赔付列表缓存*/
    KC142,
    /** 广告赔付状态*/
    KC143,
    /** 刷新特殊素材缓存*/
    KC144,
    /** ocpc测试白名单钉钉提醒*/
    KC145,
    /** 广告配置包达到限流app的缓存*/
    KC146,
    /** 广告配置包达到限流slot的缓存*/
    KC147,
    /**DSP平台adx广告缓存*/
    KC148,
    /** rta投放缓存更新*/
    KC149,
    ;
    
    /**
     * 应用标识 tuia-core
     */
    private static final String APPNAME = "TUIA";
    
    public String toString() {
        return APPNAME + "_" + super.toString();
    }
}
